@@ -6,27 +6,14 @@ use strict;
 use warnings;
 use Type::Library -base;
 use Type::Utils -all;
-
-# there is no :all, so we need to hardcode the list
-use Type::Params qw(
-  compile
-  compile_named
-  multisig
-  validate
-  validate_named
-  compile_named_oo
-  Invocant
-  wrap_subs
-  wrap_methods
-  ArgsObject
-);
+use Type::Params ':all';
 
 # EXPORT_OK, but not :all
 use Types::Standard qw(
   slurpy
 );
 
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 our @EXPORT_OK;
 
 BEGIN {
@@ -62,7 +49,7 @@ MooseX::Extended::Types - Keep our type tools organized
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 SYNOPSIS
 
